@@ -1494,6 +1494,17 @@ def pseudoInverseTrapFilter(waves, templates, baselines, rise, top, tau,
 								rise, top, filtert0=filtert0, searchRange = searchRange, 
 								t0Weight = t0Weight, batchsize = batchsize, dtype=np.float64, shift = shift)
 		return results.compute()
+
+
+@numba.jit
+def doubleExpP0Est(x):
+	offset = x[0:800].mean()
+	amp = np.max(x)-offset
+	t0 = np.argmax(x)
+	decay1 = 1250.0
+	decay2 = 10
+	return [amp, t0, decay1, decay2, offset]
+
 @numba.jit
 def doubleExp(x, amp, t0, decay1, decay2, offset):
 	"""
@@ -1756,7 +1767,7 @@ def extractDecayRate(waves, pretrigger = None, start=0, stop=-1, guess = 1250):
 	else:
 		return None
 
-def fitWaveforms(waves, pretrigger, function = 'doubleExp', region = None, residuals = False, showErrs = True, **kwargs):
+def fitWaveforms(waves, pretrigger, function = 'doubleExp', p0func = None, region = None, residuals = False, showErrs = True, **kwargs):
 	"""
 	This function fits the waveforms to a variety of functions and returns the fit parameters and covariance matrix.
 	Parameters
@@ -1770,6 +1781,9 @@ def fitWaveforms(waves, pretrigger, function = 'doubleExp', region = None, resid
 			'sigmoid': not defined yet
 		if function:
 			an arbitrarily defined function
+	p0func: None, function
+		If None, defaults to the standard behavior for the 'doubleExp' function
+		If function, this function is called to find estimates for the initial fit parameters
 	region: None, int, or np.ndarray
 		The region to be fit
 		If None: the whole waveform
@@ -1816,6 +1830,8 @@ def fitWaveforms(waves, pretrigger, function = 'doubleExp', region = None, resid
 			print('unrecognized region input, expects None, int, or np.ndarray')
 			return None
 		numArgs = len(inspect.signature(fitFunc).parameters)-1
+		if p0func is None:
+			p0func = doubleExpP0Est
 		def fitWave(wave, residuals = False, **kwargs):
 			res = None
 			if residuals == False:
@@ -1823,8 +1839,9 @@ def fitWaveforms(waves, pretrigger, function = 'doubleExp', region = None, resid
 			else:
 				res = np.zeros(numArgs*(numArgs + 1) + len(wave))
 			res[:] = np.nan
+			p0 = p0func(wave)
 			try:
-				popt, pcov = curve_fit(fitFunc, xvals, wave, **kwargs)
+				popt, pcov = curve_fit(fitFunc, xvals, wave, p0=p0, **kwargs)
 				res[:numArgs] = popt[:]
 				res[numArgs:numArgs*(numArgs + 1)] = pcov.flatten()
 				if residuals:
